==> musashi-1.0.0.tar.gz: musashi-1.0.0/cmd/xtcut.c <==
/*============================================================================*/
/* ѹ                                                                   */
/*----------------------------------------------------------------------------*/
/* 1.0 : APIб 2003/06/20                                           */
/*============================================================================*/

#include <musashi.h>
#include <stdlib.h>

#include <xtcutHelp.h>
struct mssComHelp comHelp={
  "xtcut",        /* ޥ̾       */
  "1.0",          /* С       */
  HELPT,          /* ޥɥȥ */
  HELPS,          /*              */
  HELPE,          /*              */
  HELPR,          /* ȥޥ     */
  HELPA,          /* Ծ         */
  HELPB,          /* ХݡȾ */
  HELPH           /* ۡڡ     */
};

extern struct mssGlobalVariables mssGV;

int main(int argc, char *argv[]){
/*============================================================================*/
/* ץ                                                       */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* оݹ                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptFLD optFLD={
    OFLD,   /* ץ󥿥                                             */
    "f",    /* (ʣʸԲ)                                   */
    1,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    MssFieldMaxCnt, /* ǽʺܿ                                 */
    "i",    /* оݤȤϥǡΥ(GUI)                  */
    1,      /* ɽĤ뤫ɤ(0:Բ,1:)                      */
    1,      /* ̾Ǥ뤫ɤ(0:Բ,1:)                    */
    NULL,   /* ܥץ(%ʲ)ǻǽʸ                        */
            /* ex) ԲĤξNULL, "nr": "-f ̾%rn"λǽ     */
    FLDT,   /* ΥץΥȥ(Helpɽ)                         */
    FLDC,   /* ΥץΥ(Helpɽ)                         */
    FLDF    /* ե饰ˤĤƤ(Helpɽ)ʣξϥޤǶڤ   */
  };

/*----------------------------------------------------------------------------*/
/* ȿžե饰                                                         */
/*----------------------------------------------------------------------------*/
  MssOptFLG optREV={
    OFLG,   /* ץ󥿥                                             */
    "r",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    REVT,   /* ΥץΥȥ(Helpɽ)                         */
    REVC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ϥե                                                               */
/*----------------------------------------------------------------------------*/
  MssOptINF optINF={
    OINF,   /* ץ󥿥                                             */
    "i",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    1,      /* ǽκե                                     */
    0,      /*1:file not foundΥ顼ǽλʤ 0:                   */
    INFT,   /* ΥץΥȥ(Helpɽ)                         */
    INFC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ϥե                                                               */
/*----------------------------------------------------------------------------*/
  MssOptOTF optOTF={
    OOTF,   /* ץ󥿥                                             */
    "o",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    OTFT,   /* ΥץΥȥ(Helpɽ)                         */
    OTFC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ̽                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptFLG optZIP={
    OFLG,   /* ץ󥿥                                             */
    "z",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    ZIPT,   /* ΥץΥȥ(Helpɽ)                         */
    ZIPC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* plain text                                                                 */
/*----------------------------------------------------------------------------*/
  MssOptFLG optTXT={
    OFLG,   /* ץ󥿥                                             */
    "t",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    TXTT,   /* ΥץΥȥ(Helpɽ)                         */
    TXTC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ץޤȤ                                                       */
/*----------------------------------------------------------------------------*/
  void *opt[]={&optFLD,&optREV,&optINF,&optOTF,&optZIP,&optTXT,NULL};

/*============================================================================*/
/* ѿ                                                             */
/*============================================================================*/
  struct mssHeader *hdi; /*ϥե<head>Ǽ¤*/
  struct mssHeader *hdo; /*ϥե<head>Ǽ¤*/
  struct mssFPR    *fpr; /*ϥե빽¤                */
  struct mssFPW    *fpw; /*ϥե빽¤                */
  struct mssFldRec *fr;  /*-ԥХåե¤             */

  int *revFld=NULL;   /*-rνϹܥե饰          */
  int  revCnt=0;      /*-rνϹܿ              */

  int i;

/*----------------------------------------------------------------------------*/
/*                                                                      */
/*----------------------------------------------------------------------------*/
  mssInit(argc,argv,&comHelp);       /* ʥʤɤν              */
  mssHelpDoc(opt,&comHelp,argc,argv);/* إ                                */
  mssSetOption(opt,argc,argv);       /* ޥɥץ              */
  fpr=mssOpenFPR(optINF.str,4);      /* ϥե륪ץ                  */
  hdi=mssReadHeader(fpr);            /* إåɤ߹                      */
  mssSetOptFld(&optFLD, hdi);        /* -f ܤإåܤ˴ϢŤ     */

/*mssShowOption(opt);*/
/*mssShowHeader(hdi);*/
            
/*----------------------------------------------------------------------------*/
/*ϥإåκȽ                                                    */
/*----------------------------------------------------------------------------*/
  /*ϥإåν(ȥΥԡ)*/                                
  hdo=mssInitCpyHeader(hdi);
    
  /*-f˻ꤵ줿ܾΤɲ*/
  if(!optREV.set){
    for(i=0; i<optFLD.flds->cnt; i++){
      mssAddFieldsByFldInfo(hdo->flds,
                        *(optFLD.flds->fi+i));
                        //*(hdi->flds->fi+MssFlds2num(optFLD.flds,i)));
    }
  /*-f˻ꤵʤäܾΤɲ*/
  }else{
    for(i=0; i<hdi->flds->cnt; i++){
      if(*(optFLD.fldNo2optNo+i)==-1){
        mssAddFieldsByFldInfo(hdo->flds, *(hdi->flds->fi+i));
      }
    }
  }

  /* Ⱦ򸡺ŬڤǤʤȾ */
  mssUpdateFieldsSortPriority(hdo->flds);

  /* ܤ˹ֹϿˤդ */                                      
  mssSetFieldsSequenceNum(hdo->flds);
    
  /*ɸϥץ+إåν*/
  fpw=mssOpenFPW(optOTF.str,optZIP.set,0);
  mssWriteHeader(hdo, fpw);

/*----------------------------------------------------------------------------*/
/*ᥤ롼                                                              */
/*----------------------------------------------------------------------------*/
  if(optREV.set){
    /*-rνϹֹ*/
    revFld=mssMalloc(sizeof(int)*hdi->flds->cnt,"xtcut");/*;ʬ*/
    revCnt=0;
    for(i=0; i<hdi->flds->cnt; i++){
      if(*(optFLD.fldNo2optNo+i)==-1){
        *(revFld+revCnt++)=i;
      }
    }
  }

  fr=mssInitFldRec(hdi->flds->cnt);

  /*ܺξ*/
  if(optREV.set){
    while( EOF != mssReadFldRec(fpr,fr) ){
      mssGV.inCnt++;
      /*ܤν񤭽Ф*/
      for(i=0; i<revCnt-1; i++){
        mssWriteStr(*(fr->pnt+MssFlds2num(hdi->flds,*(revFld+i))),fpw);
        mssWriteDlm(fpw);
      }
      mssWriteStr(*(fr->pnt+MssFlds2num(hdi->flds,*(revFld+i))),fpw);
      mssWriteRet(fpw);
      mssGV.outCnt++;
    }
  /*ξ*/
  }else{
    while( EOF != mssReadFldRec(fpr,fr) ){
      mssGV.inCnt++;
      /*ܤν񤭽Ф*/
      for(i=0; i<optFLD.flds->cnt-1; i++){
        mssWriteStr(*(fr->pnt+MssFlds2num(optFLD.flds,i)),fpw);
        mssWriteDlm(fpw);
      }
      mssWriteStr(*(fr->pnt+MssFlds2num(optFLD.flds,i)),fpw);
      mssWriteRet(fpw);
      mssGV.outCnt++;
    }
  }
  mssFreeFldRec(fr);
  mssFree(revFld);

/*----------------------------------------------------------------------------*/
/*եå&λ                                                       */
/*----------------------------------------------------------------------------*/
/*printf("allocCnt=%d\n",getAllocCnt());*/
  mssWriteFooter(fpw);  /* եåν             */
  mssCloseFPR(fpr);     /* ϥեΥ     */
  mssCloseFPW(fpw);     /* ϥեΥ     */
  mssFreeHeader(hdi);   /* ϥإåΰ賫         */
  mssFreeHeader(hdo);   /* ϥإåΰ賫         */
  mssFreeOption(opt);   /* ץΰ賫         */
  mssShowEndMsg();      /* λå             */
  return(0);            /* to avoid warning message   */
}

==> musashi-1.0.1.tar.gz: musashi-1.0.1/cmd/xtcut.c <==
/*============================================================================*/
/* ѹ                                                                   */
/*----------------------------------------------------------------------------*/
/* 1.0 : APIб 2003/06/20                                           */
/* 1.1 : ̾ϤʤХ 2003/07/18                            */
/*============================================================================*/

#include <musashi.h>
#include <stdlib.h>

#include <xtcutHelp.h>
struct mssComHelp comHelp={
  "xtcut",        /* ޥ̾       */
  "1.1",          /* С       */
  HELPT,          /* ޥɥȥ */
  HELPS,          /*              */
  HELPE,          /*              */
  HELPR,          /* ȥޥ     */
  HELPA,          /* Ծ         */
  HELPB,          /* ХݡȾ */
  HELPH           /* ۡڡ     */
};

extern struct mssGlobalVariables mssGV;

int main(int argc, char *argv[]){
/*============================================================================*/
/* ץ                                                       */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* оݹ                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptFLD optFLD={
    OFLD,   /* ץ󥿥                                             */
    "f",    /* (ʣʸԲ)                                   */
    1,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    MssFieldMaxCnt, /* ǽʺܿ                                 */
    "i",    /* оݤȤϥǡΥ(GUI)                  */
    1,      /* ɽĤ뤫ɤ(0:Բ,1:)                      */
    1,      /* ̾Ǥ뤫ɤ(0:Բ,1:)                    */
    NULL,   /* ܥץ(%ʲ)ǻǽʸ                        */
            /* ex) ԲĤξNULL, "nr": "-f ̾%rn"λǽ     */
    FLDT,   /* ΥץΥȥ(Helpɽ)                         */
    FLDC,   /* ΥץΥ(Helpɽ)                         */
    FLDF    /* ե饰ˤĤƤ(Helpɽ)ʣξϥޤǶڤ   */
  };

/*----------------------------------------------------------------------------*/
/* ȿžե饰                                                         */
/*----------------------------------------------------------------------------*/
  MssOptFLG optREV={
    OFLG,   /* ץ󥿥                                             */
    "r",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    REVT,   /* ΥץΥȥ(Helpɽ)                         */
    REVC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ϥե                                                               */
/*----------------------------------------------------------------------------*/
  MssOptINF optINF={
    OINF,   /* ץ󥿥                                             */
    "i",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    1,      /* ǽκե                                     */
    0,      /*1:file not foundΥ顼ǽλʤ 0:                   */
    INFT,   /* ΥץΥȥ(Helpɽ)                         */
    INFC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ϥե                                                               */
/*----------------------------------------------------------------------------*/
  MssOptOTF optOTF={
    OOTF,   /* ץ󥿥                                             */
    "o",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    OTFT,   /* ΥץΥȥ(Helpɽ)                         */
    OTFC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ̽                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptFLG optZIP={
    OFLG,   /* ץ󥿥                                             */
    "z",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    ZIPT,   /* ΥץΥȥ(Helpɽ)                         */
    ZIPC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* plain text                                                                 */
/*----------------------------------------------------------------------------*/
  MssOptFLG optTXT={
    OFLG,   /* ץ󥿥                                             */
    "t",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    TXTT,   /* ΥץΥȥ(Helpɽ)                         */
    TXTC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ץޤȤ                                                       */
/*----------------------------------------------------------------------------*/
  void *opt[]={&optFLD,&optREV,&optINF,&optOTF,&optZIP,&optTXT,NULL};

/*============================================================================*/
/* ѿ                                                             */
/*============================================================================*/
  struct mssHeader *hdi; /*ϥե<head>Ǽ¤*/
  struct mssHeader *hdo; /*ϥե<head>Ǽ¤*/
  struct mssFPR    *fpr; /*ϥե빽¤                */
  struct mssFPW    *fpw; /*ϥե빽¤                */
  struct mssFldRec *fr;  /*-ԥХåե¤             */

  int *revFld=NULL;   /*-rνϹܥե饰          */
  int  revCnt=0;      /*-rνϹܿ              */

  int i;

/*----------------------------------------------------------------------------*/
/*                                                                      */
/*----------------------------------------------------------------------------*/
  mssInit(argc,argv,&comHelp);       /* ʥʤɤν              */
  mssHelpDoc(opt,&comHelp,argc,argv);/* إ                                */
  mssSetOption(opt,argc,argv);       /* ޥɥץ              */
  fpr=mssOpenFPR(optINF.str,4);      /* ϥե륪ץ                  */
  hdi=mssReadHeader(fpr);            /* إåɤ߹                      */
  mssSetOptFld(&optFLD, hdi);        /* -f ܤإåܤ˴ϢŤ     */

/*mssShowOption(opt);*/
/*mssShowHeader(hdi);*/
            
/*----------------------------------------------------------------------------*/
/*ϥإåκȽ                                                    */
/*----------------------------------------------------------------------------*/
  /*ϥإåν(ȥΥԡ)*/                                
  hdo=mssInitCpyHeader(hdi);
    
  /*-f˻ꤵ줿ܾΤɲ*/
  if(!optREV.set){
    for(i=0; i<optFLD.flds->cnt; i++){
      mssAddFieldsByFldInfo(hdo->flds, *(optFLD.flds->fi+i));
      mssSetFldInfoSort(*(hdo->flds->fi+i),
          mssFldNum2SrtPri(hdi->flds, MssFlds2num(optFLD.flds,i)),
          mssFldNum2SrtRev(hdi->flds, MssFlds2num(optFLD.flds,i)),
          mssFldNum2SrtNum(hdi->flds, MssFlds2num(optFLD.flds,i)) );
    }
  /*-f˻ꤵʤäܾΤɲ*/
  }else{
    for(i=0; i<hdi->flds->cnt; i++){
      if(*(optFLD.fldNo2optNo+i)==-1){
        mssAddFieldsByFldInfo(hdo->flds, *(hdi->flds->fi+i));
      }
    }
  }

  /* Ⱦ򸡺ŬڤǤʤȾ */
  mssUpdateFieldsSortPriority(hdo->flds);

  /* ܤ˹ֹϿˤդ */                                      
  mssSetFieldsSequenceNum(hdo->flds);
    
  /*ɸϥץ+إåν*/
  fpw=mssOpenFPW(optOTF.str,optZIP.set,0);
  mssWriteHeader(hdo, fpw);

/*----------------------------------------------------------------------------*/
/*ᥤ롼                                                              */
/*----------------------------------------------------------------------------*/
  if(optREV.set){
    /*-rνϹֹ*/
    revFld=mssMalloc(sizeof(int)*hdi->flds->cnt,"xtcut");/*;ʬ*/
    revCnt=0;
    for(i=0; i<hdi->flds->cnt; i++){
      if(*(optFLD.fldNo2optNo+i)==-1){
        *(revFld+revCnt++)=i;
      }
    }
  }

  fr=mssInitFldRec(hdi->flds->cnt);

  /*ܺξ*/
  if(optREV.set){
    while( EOF != mssReadFldRec(fpr,fr) ){
      mssGV.inCnt++;
      /*ܤν񤭽Ф*/
      for(i=0; i<revCnt-1; i++){
        mssWriteStr(*(fr->pnt+MssFlds2num(hdi->flds,*(revFld+i))),fpw);
        mssWriteDlm(fpw);
      }
      mssWriteStr(*(fr->pnt+MssFlds2num(hdi->flds,*(revFld+i))),fpw);
      mssWriteRet(fpw);
      mssGV.outCnt++;
    }
  /*ξ*/
  }else{
    while( EOF != mssReadFldRec(fpr,fr) ){
      mssGV.inCnt++;
      /*ܤν񤭽Ф*/
      for(i=0; i<optFLD.flds->cnt-1; i++){
        mssWriteStr(*(fr->pnt+MssFlds2num(optFLD.flds,i)),fpw);
        mssWriteDlm(fpw);
      }
      mssWriteStr(*(fr->pnt+MssFlds2num(optFLD.flds,i)),fpw);
      mssWriteRet(fpw);
      mssGV.outCnt++;
    }
  }
  mssFreeFldRec(fr);
  mssFree(revFld);

/*----------------------------------------------------------------------------*/
/*եå&λ                                                       */
/*----------------------------------------------------------------------------*/
/*printf("allocCnt=%d\n",getAllocCnt());*/
  mssWriteFooter(fpw);  /* եåν             */
  mssCloseFPR(fpr);     /* ϥեΥ     */
  mssCloseFPW(fpw);     /* ϥեΥ     */
  mssFreeHeader(hdi);   /* ϥإåΰ賫         */
  mssFreeHeader(hdo);   /* ϥإåΰ賫         */
  mssFreeOption(opt);   /* ץΰ賫         */
  mssShowEndMsg();      /* λå             */
  return(0);            /* to avoid warning message   */
}
